﻿
$ErrorActionPreference = 'Stop';

$toolsDir   = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$url        = "https://download.srcclr.com/srcclr-3.2.4-windows.zip"
$url64      = "https://download.srcclr.com/srcclr-$Env:chocolateyPackageVersion-windows.zip"

$packageArgs = @{
  packageName    = $env:ChocolateyPackageName
  unzipLocation  = $toolsDir
  fileType       = 'EXE'
  url            = $url
  url64bit       = $url64

  softwareName   = 'srcclr*'

  checksum       = '5ce02e0c1eb47661a4699d3ccdf44a171a95c84db74550f41ab1f2bdea9993fa'
  checksumType   = 'sha256'

  checksum64     = 'e0c409b7e0ed2d41f2bfbeb11e134e48591786f03bd3a1f80e6e145d2eb70d6d'
  checksumType64 = 'sha256'

  validExitCodes = @(0, 3010, 1641)
}

Install-ChocolateyZipPackage @packageArgs

function RemoveSrcclrPaths ($target) {
    $thePath = [Environment]::GetEnvironmentVariable("Path", $target)
    $thePath = ( ( $thePath -split ";" | % { if (-not ( $_ -match "srcclr" ) ) { $_ } } | ? { $_ } ) -join ";" )
    [Environment]::SetEnvironmentVariable("Path", $thePath, $target)
}

# Remove old SourceClear paths from the user and machine PATH
RemoveSrcclrPaths([EnvironmentVariableTarget]::User)
RemoveSrcclrPaths([EnvironmentVariableTarget]::Machine)

$installDir = Join-Path $toolsDir "srcclr-$Env:chocolateyPackageVersion"

# Using -PathType Machine since we want it available for all users
Install-ChocolateyPath (Join-Path $installDir 'bin') -PathType Machine

$files = get-childitem $installDir -include *.exe -recurse

foreach ($file in $files) {
  New-Item "$file.ignore" -type file -force | Out-Null
}
